﻿using Hotline.Orders;
using Hotline.Repository.SqlSugar.CallCenter;
using Hotline.Share.Enums.Order;
using Hotline.Share.Tools;
using Shouldly;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Repository;

namespace Hotline.Application.Tests.Repository;
public class CallNativeRepositoryTest
{
    private readonly ICallNativeRepository _callNativeRepository;
    private readonly IRepository<Order> _orderRepository;

    public CallNativeRepositoryTest(ICallNativeRepository callNativeRepository, IRepository<Order> orderRepository)
    {
        _callNativeRepository = callNativeRepository;
        _orderRepository = orderRepository;
    }

    [Theory]
    [InlineData("", "DefaultSatisfied")]
    [InlineData("1", "VerySatisfied")]
    [InlineData("2", "Satisfied")]
    [InlineData("3", "Normal")]
    [InlineData("4", "NoSatisfied")]
    [InlineData("5", "VeryNoSatisfied")]
    public async Task GetReplyVoiceOrDefaultByOrderId_Test(string replyTxt, string enumString)
    {
        var order = await _orderRepository.Queryable()
            .OrderByDescending(m => m.CreationTime)
            .Where(m => m.CallId != "")
            .FirstAsync();

        await _callNativeRepository.UpdateReplyTxtAsync(order.CallId, replyTxt);

        var result = await _callNativeRepository.GetReplyVoiceOrDefaultByOrderIdAsync(order.Id);
        result.ShouldBe(enumString.ToEnum<EVoiceEvaluate>());
    }
}
