﻿using Hotline.CallCenter.Calls;
using Hotline.Orders;
using Hotline.Repository.SqlSugar.DataPermissions;
using Hotline.Settings;
using Hotline.Share.Enums.Order;
using Hotline.Share.Tools;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Dependency;
using XF.Domain.Repository;

namespace Hotline.Repository.SqlSugar.CallCenter;
public class CallNativeRepository : BaseRepository<CallNative>, ICallNativeRepository, IScopeDependency
{
    private readonly IRepository<Order> _orderRepository;
    public CallNativeRepository(ISugarUnitOfWork<HotlineDbContext> uow, IDataPermissionFilterBuilder dataPermissionFilterBuilder, IRepository<Order> orderRepository) : base(uow, dataPermissionFilterBuilder)
    {
        _orderRepository = orderRepository;
    }

    public async Task<int> UpdateReplyTxtAsync(string callId, string replyTxt)
    {
        return await Updateable()
            .Where(m => m.Id == callId)
            .SetColumns(m => m.ReplyTxt, replyTxt)
            .ExecuteCommandAsync();
    }

    public async Task<CallNative?> GetByOrderIdAsync(string orderId)
    {
        var callId = await _orderRepository
            .Queryable()
            .Where(m => m.Id == orderId)
            .Select(m => m.CallId)
            .FirstAsync();
        if (callId.IsNullOrEmpty())
            return null;
        return await GetAsync(callId);
    }

    public async Task<EVoiceEvaluate> GetReplyVoiceOrDefaultByOrderIdAsync(string orderId)
    {
        var callNative = await GetByOrderIdAsync(orderId);
        if (callNative is null || callNative.ReplyTxt.IsNullOrEmpty())
            return EVoiceEvaluate.DefaultSatisfied;

        var replyTxt = callNative.ReplyTxt.Trim();
        if (SettingConstants.ReplyToEnumMap.TryGetValue(replyTxt, out var result))
        {
            var replySplit = result.Split('|');
            return replySplit[3].ToEnum<EVoiceEvaluate>();
        }
        return EVoiceEvaluate.DefaultSatisfied;
    }
}
